@@ -1,13 +1,14 @@
 #include "libsoup/soup.h"
 
 int LLVMFuzzerTestOneInput (const unsigned char *data, size_t size);
+static int set_logger = 0;
 
 #ifdef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
 static GLogWriterOutput
 empty_logging_func (GLogLevelFlags log_level, const GLogField *fields,
                     gsize n_fields, gpointer user_data)
 {
-  return G_LOG_WRITER_HANDLED;
+        return G_LOG_WRITER_HANDLED;
 }
 #endif
 
@@ -16,6 +17,10 @@ static void
 fuzz_set_logging_func (void)
 {
 #ifdef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
-  g_log_set_writer_func (empty_logging_func, NULL, NULL);
+        if (!set_logger)
+        {
+                set_logger = 1;
+                g_log_set_writer_func (empty_logging_func, NULL, NULL);
+        }
 #endif
 }
