@@ -27,15 +27,9 @@ typedef struct _SoupServer              SoupServer;
 typedef struct _SoupServerMessage       SoupServerMessage;
 typedef struct _SoupSession             SoupSession;
 typedef struct _SoupSessionFeature      SoupSessionFeature;
-typedef struct _SoupSocket              SoupSocket;
 typedef struct _SoupWebsocketConnection SoupWebsocketConnection;
 typedef struct _SoupWebsocketExtension  SoupWebsocketExtension;
 
-/*< private >*/
-typedef struct _SoupConnection        SoupConnection;
-typedef struct _SoupMessageQueue      SoupMessageQueue;
-typedef struct _SoupMessageQueueItem  SoupMessageQueueItem;
-
 G_END_DECLS
 
 #endif /* __SOUP_TYPES_H__ */
