@@ -23,6 +23,7 @@
 #include <string.h>
 
 #include "soup-websocket-connection.h"
+#include "soup-websocket-connection-private.h"
 #include "soup-enum-types.h"
 #include "soup-io-stream.h"
 #include "soup-uri-utils-private.h"
@@ -75,6 +76,7 @@ enum {
 	PROP_STATE,
 	PROP_MAX_INCOMING_PAYLOAD_SIZE,
 	PROP_KEEPALIVE_INTERVAL,
+	PROP_KEEPALIVE_PONG_TIMEOUT,
 	PROP_EXTENSIONS,
 
         LAST_PROPERTY
@@ -119,6 +121,14 @@ typedef struct {
 	char *protocol;
 	guint64 max_incoming_payload_size;
 	guint keepalive_interval;
+	guint keepalive_pong_timeout;
+	guint64 last_keepalive_seq_num;
+
+	/* Each keepalive ping uses a unique payload. This hash table uses such
+	 * a ping payload as a key to the corresponding GSource that will
+	 * timeout if the pong is not received in time.
+	 */
+	GHashTable *outstanding_pongs;
 
 	gushort peer_close_code;
 	char *peer_close_data;
@@ -142,6 +152,12 @@ typedef struct {
 	guint8 message_opcode;
 	GByteArray *message_data;
 
+	/* Only for use by the libsoup test suite. Can be removed at any point.
+	 * Activating this violates RFC 6455 Section 5.5.2 which stipulates that
+	 * a ping MUST always be replied with a pong.
+	 */
+	gboolean suppress_pongs_for_tests;
+
 	GSource *keepalive_timeout;
 
 	GList *extensions;
@@ -151,6 +167,11 @@ typedef struct {
 #define READ_BUFFER_SIZE 1024
 #define MASK_LENGTH 4
 
+/* If a pong payload begins with these bytes, we assume it is a pong from one of
+ * our keepalive pings.
+ */
+#define KEEPALIVE_PAYLOAD_PREFIX "libsoup-keepalive-"
+
 G_DEFINE_FINAL_TYPE_WITH_PRIVATE (SoupWebsocketConnection, soup_websocket_connection, G_TYPE_OBJECT)
 
 static void queue_frame (SoupWebsocketConnection *self, SoupWebsocketQueueFlags flags,
@@ -299,6 +320,7 @@ soup_websocket_connection_start_input_source (SoupWebsocketConnection *self)
 		return;
 
 	priv->input_source = g_pollable_input_stream_create_source (priv->input, NULL);
+	g_source_set_static_name (priv->input_source, "SoupWebsocketConnection input");
 	g_source_set_callback (priv->input_source, (GSourceFunc)on_web_socket_input, self, NULL);
 	g_source_attach (priv->input_source, g_main_context_get_thread_default ());
 }
@@ -325,6 +347,7 @@ soup_websocket_connection_start_output_source (SoupWebsocketConnection *self)
 		return;
 
 	priv->output_source = g_pollable_output_stream_create_source (priv->output, NULL);
+	g_source_set_static_name (priv->output_source, "SoupWebsocketConnection output");
 	g_source_set_callback (priv->output_source, (GSourceFunc)on_web_socket_output, self, NULL);
 	g_source_attach (priv->output_source, g_main_context_get_thread_default ());
 }
@@ -354,6 +377,14 @@ keepalive_stop_timeout (SoupWebsocketConnection *self)
 	}
 }
 
+static void
+keepalive_stop_outstanding_pongs (SoupWebsocketConnection *self)
+{
+        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
+
+        g_clear_pointer (&priv->outstanding_pongs, g_hash_table_destroy);
+}
+
 static void
 close_io_stop_timeout (SoupWebsocketConnection *self)
 {
@@ -372,6 +403,7 @@ close_io_stream (SoupWebsocketConnection *self)
 	SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
 
 	keepalive_stop_timeout (self);
+	keepalive_stop_outstanding_pongs (self);
 	close_io_stop_timeout (self);
 
 	if (!priv->io_closing) {
@@ -437,6 +469,7 @@ close_io_after_timeout (SoupWebsocketConnection *self)
 
 	g_debug ("waiting %d seconds for peer to close io", timeout);
 	priv->close_timeout = g_timeout_source_new_seconds (timeout);
+	g_source_set_static_name (priv->close_timeout, "SoupWebsocketConnection close timeout");
 	g_source_set_callback (priv->close_timeout, on_timeout_close_io, self, NULL);
 	g_source_attach (priv->close_timeout, g_main_context_get_thread_default ());
 }
@@ -578,6 +611,7 @@ send_close (SoupWebsocketConnection *self,
 	priv->close_sent = TRUE;
 
 	keepalive_stop_timeout (self);
+	keepalive_stop_outstanding_pongs (self);
 }
 
 static void
@@ -806,9 +840,13 @@ receive_ping (SoupWebsocketConnection *self,
                       const guint8 *data,
                       gsize len)
 {
-	/* Send back a pong with same data */
-	g_debug ("received ping, responding");
-	send_message (self, SOUP_WEBSOCKET_QUEUE_URGENT, 0x0A, data, len);
+        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
+
+        if (!priv->suppress_pongs_for_tests) {
+                /* Send back a pong with same data */
+                g_debug ("received ping, responding");
+                send_message (self, SOUP_WEBSOCKET_QUEUE_URGENT, 0x0A, data, len);
+        }
 }
 
 static void
@@ -816,10 +854,9 @@ receive_pong (SoupWebsocketConnection *self,
                       const guint8 *data,
                       gsize len)
 {
+        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
 	GByteArray *bytes;
 
-	g_debug ("received pong message");
-
 	bytes = g_byte_array_sized_new (len + 1);
 	g_byte_array_append (bytes, data, len);
 	/* Always null terminate, as a convenience */
@@ -827,6 +864,18 @@ receive_pong (SoupWebsocketConnection *self,
 	/* But don't include the null terminator in the byte count */
 	bytes->len--;
 
+        /* g_str_has_prefix() and g_hash_table_remove() are safe to use since we
+         * just made sure to null terminate bytes->data
+         */
+        if (priv->keepalive_pong_timeout > 0 && g_str_has_prefix ((const gchar *)bytes->data, KEEPALIVE_PAYLOAD_PREFIX)) {
+                if (priv->outstanding_pongs && g_hash_table_remove (priv->outstanding_pongs, bytes->data))
+                        g_debug ("received keepalive pong");
+                else
+                        g_debug ("received unknown keepalive pong");
+        } else {
+                g_debug ("received pong message");
+        }
+
 	g_signal_emit (self, signals[PONG], 0, bytes);
 	g_byte_array_unref (bytes);
 
@@ -1363,6 +1412,10 @@ soup_websocket_connection_get_property (GObject *object,
 		g_value_set_uint (value, priv->keepalive_interval);
 		break;
 
+	case PROP_KEEPALIVE_PONG_TIMEOUT:
+		g_value_set_uint (value, priv->keepalive_pong_timeout);
+		break;
+
 	case PROP_EXTENSIONS:
 		g_value_set_pointer (value, priv->extensions);
 		break;
@@ -1416,6 +1469,11 @@ soup_websocket_connection_set_property (GObject *object,
 		                                                  g_value_get_uint (value));
 		break;
 
+	case PROP_KEEPALIVE_PONG_TIMEOUT:
+		soup_websocket_connection_set_keepalive_pong_timeout (self,
+								      g_value_get_uint (value));
+		break;
+
 	case PROP_EXTENSIONS:
 		priv->extensions = g_value_get_pointer (value);
 		break;
@@ -1430,7 +1488,9 @@ static void
 soup_websocket_connection_dispose (GObject *object)
 {
 	SoupWebsocketConnection *self = SOUP_WEBSOCKET_CONNECTION (object);
-        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
+	SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
+
+	keepalive_stop_outstanding_pongs (self);
 
 	priv->dirty_close = TRUE;
 	close_io_stream (self);
@@ -1612,6 +1672,29 @@ soup_websocket_connection_class_init (SoupWebsocketConnectionClass *klass)
                                    G_PARAM_CONSTRUCT |
                                    G_PARAM_STATIC_STRINGS);
 
+        /**
+         * SoupWebsocketConnection:keepalive-pong-timeout:
+         *
+         * Timeout in seconds for when the absence of a pong from a keepalive
+         * ping is assumed to be caused by a faulty connection. The WebSocket
+         * will be transitioned to a closed state when this happens.
+         *
+         * If set to 0 then the absence of pongs from keepalive pings is
+         * ignored.
+         *
+         * Since: 3.6
+         */
+        properties[PROP_KEEPALIVE_PONG_TIMEOUT] =
+                g_param_spec_uint ("keepalive-pong-timeout",
+                                   "Keepalive pong timeout",
+                                   "Keepalive pong timeout",
+                                   0,
+                                   G_MAXUINT,
+                                   0,
+                                   G_PARAM_READWRITE |
+                                   G_PARAM_CONSTRUCT |
+                                   G_PARAM_STATIC_STRINGS);
+
         /**
          * SoupWebsocketConnection:extensions:
          *
@@ -2114,15 +2197,97 @@ soup_websocket_connection_get_keepalive_interval (SoupWebsocketConnection *self)
 }
 
 static gboolean
-on_queue_ping (gpointer user_data)
+on_pong_timeout (gpointer user_data)
 {
-	SoupWebsocketConnection *self = SOUP_WEBSOCKET_CONNECTION (user_data);
-	static const char ping_payload[] = "libsoup";
+        SoupWebsocketConnection *self = SOUP_WEBSOCKET_CONNECTION (user_data);
+        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
 
+        g_debug ("expected pong never arrived; connection probably lost");
+
+        GError *error = g_error_new (SOUP_WEBSOCKET_ERROR,
+                                     SOUP_WEBSOCKET_CLOSE_POLICY_VIOLATION,
+                                     "Did not receive keepalive pong within %d seconds",
+                                     priv->keepalive_pong_timeout);
+        emit_error_and_close (self, g_steal_pointer (&error), FALSE /* to ignore error if already closing */);
+
+        return G_SOURCE_REMOVE;
+}
+
+static GSource *
+new_pong_timeout_source (SoupWebsocketConnection *self, int pong_timeout)
+{
+        GSource *source = g_timeout_source_new_seconds (pong_timeout);
+        g_source_set_static_name (source, "SoupWebsocketConnection pong timeout");
+        g_source_set_callback (source, on_pong_timeout, self, NULL);
+        g_source_attach (source, g_main_context_get_thread_default ());
+        return source;
+}
+
+static void
+destroy_and_unref (gpointer data)
+{
+        GSource *source = data;
+
+        g_source_destroy (source);
+        g_source_unref (source);
+}
+
+/**
+ * register_outstanding_pong:
+ * @ping_payload: (transfer full): The payload. Note the transfer of ownership.
+ */
+static void
+register_outstanding_pong (SoupWebsocketConnection *self, char *ping_payload, guint pong_timeout)
+{
+        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
+
+        if (!priv->outstanding_pongs) {
+                priv->outstanding_pongs = g_hash_table_new_full (g_str_hash, g_str_equal,
+                                                                 g_free, destroy_and_unref);
+        }
+
+        g_hash_table_insert (priv->outstanding_pongs,
+                             ping_payload,
+                             new_pong_timeout_source (self, pong_timeout));
+}
+
+static void
+send_ping (SoupWebsocketConnection *self, const guint8 *ping_payload, gsize length)
+{
 	g_debug ("sending ping message");
 
 	send_message (self, SOUP_WEBSOCKET_QUEUE_NORMAL, 0x09,
-		      (guint8 *) ping_payload, strlen(ping_payload));
+		      ping_payload, length);
+}
+
+static gboolean
+on_keepalive_timeout (gpointer user_data)
+{
+	SoupWebsocketConnection *self = SOUP_WEBSOCKET_CONNECTION (user_data);
+        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
+
+        /* We need to be able to uniquely identify each ping so that we can
+         * bookkeep what pongs we are still missing. Since we use TCP as
+         * transport, we don't need to worry about some pings and pongs getting
+         * lost. An ascending sequence number will work fine to uniquely
+         * identify pings.
+         *
+         * Even with G_MAXUINT64 this string is well within the 125 byte ping
+         * payload limit.
+         */
+        priv->last_keepalive_seq_num++;
+        char *ping_payload = g_strdup_printf (KEEPALIVE_PAYLOAD_PREFIX "%" G_GUINT64_FORMAT,
+                                              priv->last_keepalive_seq_num);
+
+        /* We fully control the payload, so we know it is safe to print. */
+        g_debug ("ping %s", ping_payload);
+
+	send_ping (self, (guint8 *) ping_payload, strlen(ping_payload));
+        if (priv->keepalive_pong_timeout > 0) {
+                register_outstanding_pong (self, g_steal_pointer (&ping_payload), priv->keepalive_pong_timeout);
+        } else {
+                g_clear_pointer (&ping_payload, g_free);
+        }
 
 	return G_SOURCE_CONTINUE;
 }
@@ -2153,8 +2318,68 @@ soup_websocket_connection_set_keepalive_interval (SoupWebsocketConnection *self,
 
 		if (interval > 0) {
 			priv->keepalive_timeout = g_timeout_source_new_seconds (interval);
-			g_source_set_callback (priv->keepalive_timeout, on_queue_ping, self, NULL);
+			g_source_set_static_name (priv->keepalive_timeout, "SoupWebsocketConnection keepalive timeout");
+			g_source_set_callback (priv->keepalive_timeout, on_keepalive_timeout, self, NULL);
 			g_source_attach (priv->keepalive_timeout, g_main_context_get_thread_default ());
 		}
 	}
 }
+
+/**
+ * soup_websocket_connection_get_keepalive_pong_timeout:
+ * @self: the WebSocket
+ *
+ * Gets the keepalive pong timeout in seconds or 0 if disabled.
+ *
+ * Returns: the keepalive pong timeout.
+ *
+ * Since: 3.6
+ */
+guint
+soup_websocket_connection_get_keepalive_pong_timeout (SoupWebsocketConnection *self)
+{
+        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
+
+        g_return_val_if_fail (SOUP_IS_WEBSOCKET_CONNECTION (self), 0);
+
+        return priv->keepalive_pong_timeout;
+}
+
+/**
+ * soup_websocket_connection_set_keepalive_pong_timeout:
+ * @self: the WebSocket
+ * @pong_timeout: the timeout in seconds
+ *
+ * Set the timeout in seconds for when the absence of a pong from a keepalive
+ * ping is assumed to be caused by a faulty connection.
+ *
+ * If set to 0 then the absence of pongs from keepalive pings is ignored.
+ *
+ * Since: 3.6
+ */
+void
+soup_websocket_connection_set_keepalive_pong_timeout (SoupWebsocketConnection *self,
+                                                      guint pong_timeout)
+{
+        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
+
+        g_return_if_fail (SOUP_IS_WEBSOCKET_CONNECTION (self));
+
+        if (priv->keepalive_pong_timeout != pong_timeout) {
+                priv->keepalive_pong_timeout = pong_timeout;
+                g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_KEEPALIVE_PONG_TIMEOUT]);
+        }
+
+        if (priv->keepalive_pong_timeout == 0) {
+                keepalive_stop_outstanding_pongs (self);
+        }
+}
+
+void
+soup_websocket_connection_set_suppress_pongs_for_tests (SoupWebsocketConnection *self,
+                                                        gboolean suppress)
+{
+        SoupWebsocketConnectionPrivate *priv = soup_websocket_connection_get_instance_private (self);
+
+        priv->suppress_pongs_for_tests = suppress;
+}
